@@ -36,13 +36,13 @@ class Scene:
 
     @classmethod
     def build(cls):
-        """ Recover all the map building the things"""
+        """ Build all the things inside the Scene """
         for thing in cls.things:
             thing.build()
 
     @classmethod
     def unbuild(cls):
-        """ Recover all the map unbuilding the things """
+        """ Unbuild all the things inside the Scene """
         for thing in cls.things:
             thing.unbuild()
 
@@ -84,7 +84,8 @@ class Scene:
     def load(cls, file_path):
         """ Load a scene from a file (but no build it yet) """
         Scene.things = pickle.load(open(file_path, "rb"))
-        Scene._position = Scene.things[0].position
+        if Scene.things:
+            Scene._position = Scene.things[0].position
 
     @classmethod
     def save(cls, file_path):
